# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["DisputeStage"]

DisputeStage: TypeAlias = Literal["pre_dispute", "dispute", "pre_arbitration"]
